about summary refs log tree commit diff stats
path: root/subx/013direct_addressing.cc
diff options
context:
space:
mode:
authorKartik Agaram <vc@akkartik.com>2018-10-01 11:09:07 -0700
committerKartik Agaram <vc@akkartik.com>2018-10-01 11:09:07 -0700
commitca00f6b97c52262b39c28cccb76b52e059553f13 (patch)
tree3c6e1ea3e36c849a344eac03a468b3e853241bb3 /subx/013direct_addressing.cc
parent75e30d2faa3480ae8810856d6527089ba88346a5 (diff)
downloadmu-ca00f6b97c52262b39c28cccb76b52e059553f13.tar.gz
4634
Diffstat (limited to 'subx/013direct_addressing.cc')
-rw-r--r--subx/013direct_addressing.cc10
1 files changed, 5 insertions, 5 deletions
diff --git a/subx/013direct_addressing.cc b/subx/013direct_addressing.cc
index 45e034ed..5177252f 100644
--- a/subx/013direct_addressing.cc
+++ b/subx/013direct_addressing.cc
@@ -554,17 +554,17 @@ put(name, "5e", "pop top of stack to R6 (ESI)");
 put(name, "5f", "pop top of stack to R7 (EDI)");
 
 :(scenario pop_r32)
 % Reg[ESP].u = 0x60;
 % Mem.push_back(vma(0x1));  // manually allocate memory
 % write_mem_i32(0x60, 0x0000000a);  // ..before this write
 == 0x1  # code segment
 # op  ModR/M  SIB   displacement  immediate
   5b                                          # pop stack to EBX
-== 0x60  # data segment
+== 0x2000  # data segment
 0a 00 00 00  # 0x0a
 +run: pop into EBX
 +run: popping value 0x0000000a
-+run: incrementing ESP to 0x00000064
++run: incrementing ESP to 0x00002004
 
 :(before "End Single-Byte Opcodes")
 case 0x58:
@@ -554,17 +554,17 @@ put(name, "5e", "pop top of stack to R6 (ESI)");
 
 :(scenario pop_r32)
-% Reg[ESP].u = 0x60;
-% Mem.push_back(vma(0x1));  // manually allocate memory
-% write_mem_i32(0x60, 0x0000000a);  // ..before this write
+% Reg[ESP].u = 0x2000;
+% Mem.push_back(vma(0x2000));  // manually allocate memory
+% write_mem_i32(0x2000, 0x0000000a);  // ..before this write
 == 0x1  # code segment
 # op  ModR/M  SIB   displacement  immediate